CartValidationResult class

Constructors

CartValidationResult({required bool isValid, List<String> errors = const [], List<String> warnings = const [], Map<String, dynamic>? metadata})
const
CartValidationResult.invalid(List<String> errors)
factory
CartValidationResult.valid()
factory

Properties

errors List<String>
final
hashCode int
The hash code for this object.
no setterinherited
isValid bool
final
metadata Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
warnings List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited