Category class

Represents a product category.

Platform-agnostic category entity with support for hierarchical categories (via parentId) and product counts.

Annotations

Constructors

Category({required String id, required String name, required String slug, String? description, String? image, String? parentId, int productCount = 0, int displayOrder = 0, Map<String, dynamic>? extensions})
const
Category.fromJson(Map<String, dynamic> json)
factory

Properties

description String?
final
displayOrder int
final
extensions Map<String, dynamic>?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
id String
final
image String?
final
name String
final
parentId String?
final
productCount int
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slug String
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

copyWith({String? id, String? name, String? slug, String? description, String? image, String? parentId, int? productCount, int? displayOrder, Map<String, dynamic>? extensions}) Category
getExtension<T>(String key) → T?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.

Operators

operator ==(Object other) bool
The equality operator.
inherited