CountryState class
Represents a state, province, or region within a country.
- Annotations
Constructors
-
CountryState({required String code, required String name, String? countryCode, Map<
String, dynamic> ? extensions}) -
const
-
CountryState.fromJson(Map<
String, dynamic> json) -
factory
Properties
- code → String
-
State/province code (e.g., 'CA' for California, 'ON' for Ontario)
final
- countryCode → String?
-
Country code this state belongs to
final
-
extensions
→ Map<
String, dynamic> ? -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Full state/province name (e.g., 'California', 'Ontario')
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
copyWith(
{String? code, String? name, String? countryCode, Map< String, dynamic> ? extensions}) → CountryState -
getExtension<
T> (String key) → T? -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited