CustomTokenCredentials class
Credentials for custom token authentication.
Used for custom authentication implementations or third-party auth systems.
- Inheritance
-
- Object
- AuthCredentials
- CustomTokenCredentials
- Annotations
Constructors
-
CustomTokenCredentials({required String token, Map<
String, dynamic> ? extensions}) -
const
Properties
-
extensions
→ Map<
String, dynamic> ? -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - token → String
-
final
Methods
-
getExtension<
T> (String key) → T? -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited