EmailVerificationResult class

Constructors

EmailVerificationResult({required bool success, String? message, String? errorMessage, Map<String, dynamic>? extensions})
const
EmailVerificationResult.failure(String errorMessage)
factory
EmailVerificationResult.success({String? message})
factory

Properties

errorMessage String?
final
extensions Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
message String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited