PaymentMethod class

Constructors

PaymentMethod({required String id, required String title, required String description, bool enabled = true, int order = 0, Map<String, dynamic>? settings, String? addonKey, Map<String, dynamic>? extensions})
const
PaymentMethod.fromJson(Map<String, dynamic> json)
factory

Properties

addonKey String?
Optional addon widget key to display when this method is selected Example: 'stripe.card_form', 'paypal.redirect_info' The addon will be loaded from WidgetRegistry when method is selected
final
description String
final
enabled bool
final
extensions Map<String, dynamic>?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
id String
final
order int
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings Map<String, dynamic>?
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
title String
final

Methods

getExtension<T>(String key) → T?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited