ProductReviewStats class

Represents aggregated product review statistics and rating distribution.

Annotations

Constructors

ProductReviewStats({required double averageRating, required int reviewCount, required Map<int, int> ratingDistribution, Map<String, dynamic>? extensions})
const

Properties

averageRating double
final
extensions Map<String, dynamic>?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
ratingDistribution Map<int, int>
final
reviewCount int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

getExtension<T>(String key) → T?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited