RefundResult class

Constructors

RefundResult({required bool success, String? refundId, double? refundedAmount, String? errorMessage, Map<String, dynamic>? metadata})
const
RefundResult.failure(String errorMessage)
factory
RefundResult.success({required String refundId, required double refundedAmount})
factory

Properties

errorMessage String?
final
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>?
final
refundedAmount double?
final
refundId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited