SectionConfig class

Configuration for product or content sections.

Constructors

SectionConfig({required String name, required String description, bool active = true, Map<String, dynamic> settings = const {}})
const
SectionConfig.fromJson(Map<String, dynamic> json)
factory

Properties

active bool
final
description String
final
hashCode int
The hash code for this object.
no setteroverride
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings Map<String, dynamic>
final

Methods

copyWith({String? name, String? description, bool? active, Map<String, dynamic>? settings, Map<String, dynamic>? extensions}) SectionConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override