StoreRepository class abstract

Repository for store metadata and configuration.

Provides access to store-wide settings, legal information, physical locations, and other store-related data.

Inheritance

Constructors

StoreRepository()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

findNearestStores({required double latitude, required double longitude, double radius = 50.0, int limit = 10}) Future<List<Address>>
Find nearest store locations to coordinates
getAllPolicyUrls() Future<Map<String, String>>
Get all policy links
getAllSettings() Future<Map<String, dynamic>>
Get all store settings
getContactEmail() Future<String?>
Get store contact email
getContactPhone() Future<String?>
Get store contact phone
getCookiePolicyUrl() Future<String?>
Get Cookie Policy link
getOperatingHours() Future<Map<String, String>?>
Get store operating hours
getPrivacyPolicyUrl() Future<String?>
Get Privacy Policy link
getRefundPolicyUrl() Future<String?>
Get Refund Policy link
getReturnPolicyUrl() Future<String?>
Get Return Policy link
getSetting({required String key, dynamic defaultValue}) Future
Get a custom store setting by key
getSettings({required List<String> keys}) Future<Map<String, dynamic>>
Get multiple store settings
getShippingPolicyUrl() Future<String?>
Get Shipping Policy link
Get a specific social media link
Get social media links
getStoreCurrency() Future<String>
Get store currency
getStoreDescription() Future<String?>
Get store description
getStoreInfo() Future<Map<String, dynamic>>
Get basic store information
getStoreLocation({required String locationId}) Future<Address?>
Get a specific store location by ID
getStoreLocations({String? locationType}) Future<List<Address>>
Get all physical store locations
getStoreLogoUrl() Future<String?>
Get store logo URL
getStoreName() Future<String>
Get store name
getStoreTimezone() Future<String?>
Get store timezone
getSupportEmail() Future<String?>
Get customer support email
getSupportPhone() Future<String?>
Get customer support phone
getTermsOfServiceUrl() Future<String?>
Get Terms of Service (ToS) link
initialize() → void
Initialize the repository
inherited
isStoreOpen({String? locationId}) Future<bool>
Check if store is currently open
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited