ActionRegistry class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearCustomHandlers(
) → void -
getRegisteredHandlers(
) → List< String> -
handleInteraction(
BuildContext context, UserInteraction? interaction) → void -
hasCustomHandler(
String actionId) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerCustomHandler(
String actionId, CustomActionHandler handler) → void -
registerMultipleHandlers(
Map< String, CustomActionHandler> handlers) → void -
toString(
) → String -
A string representation of this object.
inherited
-
unregisterCustomHandler(
String actionId) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited