AddonRegistry class
Constructors
- AddonRegistry()
-
Get the singleton instance
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build<
T> (String name, BuildContext context, {Map< String, dynamic> ? data, void onEvent(String event, dynamic payload)?}) → List<Widget> -
clearAddons(
String name) → void -
clearAllAddons(
) → void -
getAddonCount(
String name) → int -
getRegisteredAddons(
) → List< String> -
hasAddon(
String name) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
String name, WidgetBuilderFn builder, {int priority = 1}) → void -
removeAddon(
String name, WidgetBuilderFn builder) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → AddonRegistry
-
Named constructor for explicit access
no setter