CheckoutRequest class
- Annotations
Constructors
Properties
- billingAddress → Address?
-
final
- cartId → String
-
final
-
couponCodes
→ List<
String> ? -
final
- customerNote → String?
-
final
-
extensions
→ Map<
String, dynamic> ? -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- paymentMethodId → String?
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shippingAddress → Address?
-
final
- shippingMethodId → String?
-
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
copyWith(
{String? cartId, Address? billingAddress, Address? shippingAddress, String? shippingMethodId, String? paymentMethodId, String? customerNote, List< String> ? couponCodes, Map<String, dynamic> ? extensions}) → CheckoutRequest -
getExtension<
T> (String key) → T? -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited