CheckoutResult class
Constructors
-
CheckoutResult({required bool success, Order? order, String? errorMessage, PaymentStatus? paymentStatus, String? redirectUrl, Map<
String, dynamic> ? metadata}) -
const
- CheckoutResult.failure(String errorMessage)
-
factory
- CheckoutResult.success({required Order order, PaymentStatus? paymentStatus, String? redirectUrl})
-
factory
Properties
- errorMessage → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metadata
→ Map<
String, dynamic> ? -
final
- order → Order?
-
final
- paymentStatus → PaymentStatus?
-
final
- redirectUrl → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited