HookRegistry class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearAllHooks(
) → void -
clearHooks(
String hookName) → void -
execute<
T> (String hookName, T data) → T -
Execute all hooks for
hookNamesynchronously, threadingdatathrough each callback in priority order. -
executeAsync<
T> (String hookName, T data) → Future< T> -
Execute all hooks for
hookNameasynchronously, threadingdatathrough each callback in priority order and awaiting each result. -
getHookCount(
String hookName) → int -
getRegisteredHooks(
) → List< String> -
hasHook(
String hookName) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
String hookName, dynamic callback(dynamic), {int priority = 1}) → void -
removeHook(
String hookName, dynamic callback(dynamic)) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited