NotificationSettings class
Represents notification settings and preferences for the user.
- Annotations
Constructors
Properties
- enabled → bool
-
final
-
enabledTypes
→ Set<
String> -
final
-
extensions
→ Map<
String, dynamic> ? -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- playSound → bool
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showBadge → bool
-
final
- showInForeground → bool
-
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
copyWith(
{bool? enabled, bool? showInForeground, bool? playSound, bool? showBadge, Set< String> ? enabledTypes, Map<String, dynamic> ? extensions}) → NotificationSettings -
getExtension<
T> (String key) → T? -
inherited
-
isTypeEnabled(
String type) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited