ProductAttribute class
Represents a product attribute such as size, color, or material.
- Annotations
Constructors
Properties
-
extensions
→ Map<
String, dynamic> ? -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- name → String
-
final
-
options
→ List<
String> -
final
- position → int
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slug → String
-
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - variation → bool
-
final
- visible → bool
-
final
Methods
-
copyWith(
{String? id, String? name, String? slug, List< String> ? options, bool? visible, bool? variation, int? position, Map<String, dynamic> ? extensions}) → ProductAttribute -
getExtension<
T> (String key) → T? -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String - A string representation of this object.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited