PushNotification class
- Annotations
Constructors
-
PushNotification({required String id, required String title, required String body, String? imageUrl, Map<
String, dynamic> ? data, String? type, String? route, Map<String, dynamic> ? routeParameters, String? externalUrl, required DateTime receivedAt, bool isRead = false, bool receivedInForeground = false, NotificationPriority priority = NotificationPriority.defaultPriority, int? badge, String? sound, String? channelId, Map<String, dynamic> ? extensions}) -
const
Properties
- badge → int?
-
final
- body → String
-
final
- channelId → String?
-
final
-
data
→ Map<
String, dynamic> ? -
final
-
extensions
→ Map<
String, dynamic> ? -
finalinherited
- externalUrl → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
no setter
- id → String
-
final
- imageUrl → String?
-
final
- isRead → bool
-
final
- priority → NotificationPriority
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- receivedAt → DateTime
-
final
- receivedInForeground → bool
-
final
- route → String?
-
final
-
routeParameters
→ Map<
String, dynamic> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sound → String?
-
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - summary → String
-
no setter
- title → String
-
final
- type → String?
-
final
Methods
-
copyWith(
{String? id, String? title, String? body, String? imageUrl, Map< String, dynamic> ? data, String? type, String? route, Map<String, dynamic> ? routeParameters, String? externalUrl, DateTime? receivedAt, bool? isRead, bool? receivedInForeground, NotificationPriority? priority, int? badge, String? sound, String? channelId, Map<String, dynamic> ? extensions}) → PushNotification -
getExtension<
T> (String key) → T? -
inherited
-
markAsRead(
) → PushNotification -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String - A string representation of this object.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited